![PsiZ logo](docs/img/full_logo_300.png)

# PsiZ Datasets
[![PyPI version](https://badge.fury.io/py/psiz-datasets.svg)](https://badge.fury.io/py/psiz-datasets)
[![Python](https://img.shields.io/pypi/pyversions/psiz-datasets.svg?style=plastic)](https://badge.fury.io/py/psiz-datasets)
[![codecov](https://codecov.io/github/psiz-org/psiz-datasets/graph/badge.svg?token=2ENUG6MC37)](https://codecov.io/github/psiz-org/psiz-datasets)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

---
**WARNING:** This package is pre-release and the API is not stable. All APIs are subject to change and all releases are alpha.

---

## Purpose
Provide pre-formatted TensorFlow Datasets for hassle-free model ingestion.

## Resources
* Official Psiz Documentation: [psiz.readthedocs.io/en/latest](https://psiz.readthedocs.io/en/latest/)
* Raw JSON-formatted data files used to create TensorFlow Datasets: [osf.io psiz-datasets](https://osf.io/cn2s3/)

## Installation
There are two different ways to install: PyPI or git.

### Using PyPI
```
$ pip install psiz-datasets
```

### Using git
```
# Clone the repository from GitHub to your local machine.
$ git clone https://github.com/psiz-org/psiz-datasets.git
# Use `pip` to install the cloned repository.
$ pip install /local/path/to/psiz-datasets
```

## Contribution Guidelines
If you would like to contribute please see the [contributing guidelines](CONTRIBUTING.md).

This project uses a [Code of Conduct](CODE.md) adapted from the [Contributor Covenant](https://www.contributor-covenant.org/)
version 2.0, available at <https://www.contributor-covenant.org/version/2/0/code_of_conduct.html>.

## Licence
This project is licensed under the Apache Licence 2.0 - see LICENSE file for details.
